@@ -20,7 +20,7 @@ class HelperTestDecode(unittest.TestCase):
     @classmethod
     def setUpClass(cls) -> None:
         if cls.pool is None:
-            cls.pool = helper.get_pool()
+            cls.pool = helper.get_pool(processes=cls.processes)
         # cls.maxDiff = None
 
     # @classmethod
@@ -114,7 +114,8 @@ class HelperTestDecode(unittest.TestCase):
             self.assertEqual(len(files), self.result['count_root_files_stage3'], 'count_root_files_stage3')
 
     def encode_stage3(self):
-        encode(self.encode_dir_stage3, self.encode_dir_stage2, version=self.version, pool=self.pool)
+        encode(self.encode_dir_stage3, self.encode_dir_stage2, version=self.version, pool=self.pool,
+               file_name=os.path.basename(self.src_file))
         self.assert_stage(self.decode_dir_stage2, self.encode_dir_stage2)
         if self.result:
             files = os.listdir(self.encode_dir_stage2)
